@@ -1,5 +1,5 @@
 use crate::{PortalMessage, TcpRouterHandle};
-use async_trait::async_trait;
+use ockam_core::{async_trait, AsyncTryClone};
 use ockam_core::{route, Address, LocalMessage, Result, Routed, TransportMessage, Worker};
 use ockam_node::Context;
 use tracing::debug;
@@ -16,7 +16,7 @@ impl TcpOutletListenWorker {
         peer: String,
     ) -> Result<()> {
         let worker = Self {
-            router_handle: router_handle.clone(),
+            router_handle: router_handle.async_try_clone().await?,
             peer,
         };
 
@@ -40,7 +40,7 @@ impl Worker for TcpOutletListenWorker {
 
         debug!("Created Tcp Outlet at {}", &address);
 
-        let msg = TransportMessage::v1(route![address], msg.return_route(), msg.payload().clone());
+        let msg = TransportMessage::v1(route![address], msg.return_route(), msg.payload().to_vec());
 
         ctx.forward(LocalMessage::new(msg, vec![])).await?;
 
